@@ -1,8 +1,8 @@
 __author__ = "Shyue Ping Ong, Anubhav Jain, Michael Kocher, " + \
              "Geoffroy Hautier, William Davidson Richard, Dan Gunter, " + \
              "Shreyas Cholia, Vincent L Chevrier, Rickard Armiento"
-__date__ = "Nov 26, 2012"
-__version__ = "2.3.2"
+__date__ = "Jan 4 2013"
+__version__ = "2.4.0"
 
 #Useful aliases for commonly used objects and modules.
 
